Blueprinter: Concise interface to blueprint

Description Usage Arguments Value

Description

Create instances of blueprint's classes with a fast and concise operator. The output's class is automatically deduced from argument object.

Usage

1
symbol %bp% object

Arguments

symbol

A syntactic name, also known as an unquoted name, or a scalar character.

object

Any R value.

Value

The %bp% operator is a convenient wrapper to blueprint's constructor functions and always returns an appropriate R6 object. The output is always a Blueprint that corresponds to the underlying type of object.

If no Blueprint class corresponding to object is available, a NULL value is returned with a warning.


jeanmathieupotvin/blueprint documentation built on Jan. 17, 2021, 10:54 a.m.