Description Usage Arguments Value
Create instances of blueprint's classes with a fast and concise
operator. The output's class is automatically deduced from argument
object.
1 | symbol %bp% object
|
symbol |
A syntactic name, also known as an unquoted name, or a scalar character. |
object |
Any R value. |
The %bp% operator is a convenient wrapper to
blueprint's constructor functions and always returns an appropriate
R6 object. The output is always a Blueprint that corresponds
to the underlying type of object.
If object is a strict atomic value,
an Atomic object is returned.
If no Blueprint class corresponding to object is available, a
NULL value is returned with a warning.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.